<?php
class sydnee_main {

	function __construct() {
		// Register action/filter callbacks here...
		add_action( 'after_setup_theme', array( $this, 'sydnee_setup' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'sydnee_styles_and_scripts' ) );
		add_action( 'widgets_init', array( $this, 'sydnee_register_sidebars' ) );
	}

	function sydnee_setup() {  

		global $content_width;

		if ( ! isset( $content_width ) ) {
			$content_width = 900;
		}
		
		register_nav_menus(
	        array(
	            'primary' => __('Header Menu Area, menu_depth is 4', 'sydnee'),
	            'social' => __('Social Icon Menu Area', 'sydnee')
	        )
	    );
		
		/* image size */
		add_image_size( 'sydnee-blog-thumb', 540, 360, true );
		add_image_size( 'sydnee-about-thumb', 350, 233, true );

	    /* woocommerce */
	    add_theme_support( 'woocommerce' );
	        
	    add_theme_support( 'wc-product-gallery-zoom' );
	    add_theme_support( 'wc-product-gallery-lightbox' );
	    add_theme_support( 'wc-product-gallery-slider' );
			
		$args = array(
			'default-text-color' => '#0F8B8D',
			'width'              => 1000,
			'height'             => 250,
			'flex-width'         => true,
			'flex-height'        => true,
		);
		add_theme_support( 'custom-logo', array() );

		$args = array(
			'default-text-color' => '#0F8B8D',
			'width'              => 1000,
			'height'             => 250,
			'flex-width'         => true,
			'flex-height'        => true,
		);
		add_theme_support( 'custom-header', $args );

		add_theme_support( "custom-background", $args );

		add_theme_support( 'post-thumbnails' );

		add_theme_support( 'title-tag' );

		add_theme_support( 'customize-selective-refresh-widgets' );

		add_editor_style();

		if ( is_singular() ) {
			wp_enqueue_script( "comment-reply" );
		}
		
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'editor-styles' );
	}

	function sydnee_styles_and_scripts()
	{
	    // Enqueue Stylesheets
	    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap/bootstrap.min.css');

	    wp_enqueue_style('all', get_template_directory_uri() . '/assets/css/all.css');

	    wp_enqueue_style('owl-carousal-min', get_template_directory_uri() . '/assets/css/owl.carousel.min.css');

		wp_enqueue_style('sydnee-style', get_stylesheet_uri());
		
	    //Enqueue Scripts
	    wp_enqueue_script( 'jquery' );

	    wp_enqueue_script('bootstrap-min-js', get_template_directory_uri() . '/assets/js/bootstrap.min.js');

	    wp_enqueue_script('owl-carousel-min-js', get_template_directory_uri() . '/assets/js/owl.carousel.min.js');

	    wp_enqueue_script('sydnee-theme-script', get_template_directory_uri() . '/assets/js/sydnee-theme-script.js');

	    wp_enqueue_style('Abril_Fatface','//fonts.googleapis.com/css2?family=Abril+Fatface&display=swap');

	    /* web font */
		$font_var          = '300,400,600,700,900,300italic,400italic,600italic,700italic,900italic';
        $http              = ( ! empty( $_SERVER['HTTPS'] ) ) ? "https" : "https";
		$main_heading_font1 = get_theme_mod('main_heading_font','Playfair Display');
        $main_heading_font = str_replace( ' ' , '+', $main_heading_font1 );
		$menu_font1 = get_theme_mod('menu_font', 'Playfair Display');
        $menu_font         = str_replace( ' ' , '+', $menu_font1 );
		$theme_title1 = get_theme_mod('theme_title', 'Playfair Display');
        $theme_title       = str_replace( ' ' , '+', $theme_title1 );
		$desc_font_all1 = get_theme_mod('desc_font_all', 'Playfair Display');
        $desc_font_all     = str_replace( ' ' , '+', $desc_font_all1 );
		
        wp_enqueue_style('googleFonts', $http . '://fonts.googleapis.com/css?family=' . $main_heading_font . ':' . $font_var);	
        wp_enqueue_style('menu_font', $http . '://fonts.googleapis.com/css?family=' . $menu_font . ':' . $font_var);	
        wp_enqueue_style('theme_title', $http . '://fonts.googleapis.com/css?family=' . $theme_title . ':' . $font_var);
        wp_enqueue_style('desc_font_all', $http . '://fonts.googleapis.com/css?family=' . $desc_font_all . ':' . $font_var);

	}

	function sydnee_register_sidebars() {
		/* Register the 'primary' sidebar. */
		register_sidebar(
			array(
				'id'            => 'sidebar-primary',
				'name'          => __( 'Primary Sidebar', 'sydnee' ),
				'description'   => __( 'A sidebar for page and blog pages.', 'sydnee' ),
				'before_widget' => '<div id="%1$s" class="mwa_sidebar_widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="footer">',
				'after_title'   => '</h4>',
			)
		);

		$sydnee_widget_column = get_theme_mod('sydnee_widget_column','3');
		register_sidebar(
			array(
				'id'            => 'footer-widget',
				'name'          => __( 'Footer Widget Area', 'sydnee' ),
				'description'   => __( 'Sidebar for footer.', 'sydnee' ),
				'before_widget' => '<div id="%1$s" class="mwa_footer_widget col-lg-'.$sydnee_widget_column.' col-md-6 mt-lg-0 mt-4">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="footer">',
				'after_title'   => '</h4>',
			)
		);
	}
}
/* initialize class */
new sydnee_main();